from Components.ActionMap import ActionMap
from Components.Sources.List import List
from Screens.Screen import Screen
from Components.Pixmap import Pixmap
from Plugins.Plugin import PluginDescriptor
from Components.MenuList import MenuList
from Screens.MessageBox import MessageBox
from Screens.Standby import TryQuitMainloop
from Components.Console import Console
import time
from Components.Language import language
from Tools.Directories import resolveFilename, SCOPE_PLUGINS, SCOPE_LANGUAGE
from os import environ
import os
import gettext

lang = language.getLanguage()
environ["LANGUAGE"] = lang[:2]
gettext.bindtextdomain("enigma2", resolveFilename(SCOPE_LANGUAGE))
gettext.textdomain("enigma2")
gettext.bindtextdomain("SetupHDskin", "%s%s" % (resolveFilename(SCOPE_PLUGINS), "Extensions/SetupHDskin/locale/"))

def _(txt):
	t = gettext.dgettext("SetupHDskin", txt)
	if t == txt:
		t = gettext.gettext(txt)
	return t
        
iconpath = '/usr/lib/enigma2/python/Plugins/Extensions/SetupHDskin/icon/'                                

class SetupHDskin(Screen):
    skin = """
        <screen name="SetupHDskin" position="center,center" size="620,520" >
            <widget source="menu" render="Listbox" position="20,20" size="580,120" backgroundColor="#30000000" backgroundColorSelected="#00000000" foregroundColor="white" foregroundColorSelected="#1874CD" enableWrapAround="1" scrollbarMode="showNever" transparent="1" >
		<convert type="TemplatedMultiContent">
			{"template": [	MultiContentEntryText(pos = (40,0), size = (500,40), flags = RT_HALIGN_CENTER | RT_VALIGN_CENTER, text = 0) ],
			"fonts": [gFont("Regular", 22)],
			"itemHeight": 40}
		</convert>
            </widget> 
      </screen>"""

    def __init__(self, session):
        Screen.__init__(self, session)
        self.setTitle(_("SetupHDskin"))       
        self.session = session
        
        list = []
        list.append((_('Setup volume my_SKIN_HD'), 'Barvolume'))
        list.append((_('Available types of main menu'), 'Barmenu'))
        list.append((_('Available types of channel selector'), 'BarCS'))
        self['menu'] = List(list)
        
        self['actions'] = ActionMap(['OkCancelActions', 'DirectionActions'], {
         'cancel': self.Exit,
         'ok': self.okClick,
         'right': self.next,
         'down': self.next,
         'up': self.prev,
         'left': self.prev}, -1)

    def next(self):
        if self['menu'].getIndex() + 1 >= self['menu'].count():
            nav = 0
            self['menu'].setIndex(nav)
        else:
            self['menu'].selectNext()

    def prev(self):
        if self['menu'].getIndex() - 1 < 0:
            nav = self['menu'].count() - 1
            self['menu'].setIndex(nav)
        else:
            self['menu'].selectPrevious()            
            
    def okClick(self):
        name = self['menu'].getCurrent()
        if name is not None:
            if name[1] == 'Barvolume':
           	from Plugins.Extensions.SetupHDskin.plugin import *
           	self.session.open(VolumeS)
            elif name[1] == 'Barmenu':
           	from Plugins.Extensions.SetupHDskin.plugin import *
           	self.session.open(Mmenu)
            elif name[1] == 'BarCS':
           	from Plugins.Extensions.SetupHDskin.plugin import *
           	self.session.open(barCS)                                                                                                                                                             			

    def Exit(self):
        self.close()
        
class VolumeS(Screen):
    skin = """
        <screen name="VolumeS" position="center,center" size="620,520" >
            <widget source="menu" render="Listbox" position="20,20" size="580,120" backgroundColor="#30000000" backgroundColorSelected="#00000000" foregroundColor="white" foregroundColorSelected="#1874CD" enableWrapAround="1" scrollbarMode="showNever" transparent="1" >
		<convert type="TemplatedMultiContent">
			{"template": [	MultiContentEntryText(pos = (40,0), size = (500,40), flags = RT_HALIGN_CENTER | RT_VALIGN_CENTER, text = 0) ],
			"fonts": [gFont("Regular", 22)],
			"itemHeight": 40}
		</convert>
            </widget> 
            <widget name="logo" position="10,170" size="600,338" pixmap="/usr/lib/enigma2/python/Plugins/Extensions/SetupHDskin/icon/v.png" alphatest="blend" transparent="1" />
      </screen>"""

    def __init__(self, session):
        Screen.__init__(self, session)
        self.setTitle(_("Setup volume my_SKIN_HD"))       
        self.session = session
        self['logo'] = Pixmap()
        
        list = []
        list.append((_('Horizontal progress bar volume'), 'Horizontal', 'horizontal_bar'))
        list.append((_('Vertical progress bar volume'), 'Vertical', 'vertical_bar'))
        list.append((_('Circular progress bar volume'), 'Circular', 'circular_bar'))
        self['menu'] = List(list)
        
        self['actions'] = ActionMap(['OkCancelActions', 'DirectionActions'], {
         'cancel': self.ExitV,
         'ok': self.okClickV,
         'right': self.nextV,
         'down': self.nextV,
         'up': self.prevV,
         'left': self.prevV}, -1)

    def nextV(self):
        if self['menu'].getIndex() + 1 >= self['menu'].count():
            nav = 0
            self['menu'].setIndex(nav)
        else:
            self['menu'].selectNext()
        self.updateV()

    def prevV(self):
        if self['menu'].getIndex() - 1 < 0:
            nav = self['menu'].count() - 1
            self['menu'].setIndex(nav)
        else:
            self['menu'].selectPrevious()
        self.updateV()
        
    def updateV(self):
        if self['menu'].getCurrent()[2] == 'horizontal_bar':
            self['logo'].instance.setPixmapFromFile(iconpath + 'v.png')
        elif self['menu'].getCurrent()[2] == 'vertical_bar':
            self['logo'].instance.setPixmapFromFile(iconpath + 'v1.png')
        elif self['menu'].getCurrent()[2] == 'circular_bar':
            self['logo'].instance.setPixmapFromFile(iconpath + 'v2.png')            
            
    def okClickV(self):
        name = self['menu'].getCurrent()
        if name is not None:
            if name[1] == 'Horizontal':
                self.volO()
            elif name[1] == 'Vertical':
               	self.volV()
            elif name[1] == 'Circular':
                self.volN()
                
    def volO(self):	
        cmd = 'rm /usr/share/enigma2/my_SKIN_HD/skin_volume.xml'
        cmd1 = 'rm /usr/lib/enigma2/python/Screens/Volume.py'
        cmd2 = 'cp /usr/lib/enigma2/python/Plugins/Extensions/SetupHDskin/icon/files/1/skin_templatesVolume.xml /usr/share/enigma2/my_SKIN_HD'
        cmd3 = 'cp /usr/lib/enigma2/python/Plugins/Extensions/SetupHDskin/icon/files/1/Volume.py /usr/lib/enigma2/python/Screens'
        os.system(cmd)
        os.system(cmd1)
        os.system(cmd2)
        os.system(cmd3)
        restartbox = self.session.openWithCallback(self.restartGUI,MessageBox,_("To activate a progress bar will need to restart the system. Do it now?"), MessageBox.TYPE_YESNO, timeout = 7)		
        self.close
        
    def volV(self):	
        cmd = 'rm /usr/share/enigma2/my_SKIN_HD/skin_volume.xml'
        cmd1 = 'rm /usr/lib/enigma2/python/Screens/Volume.py'
        cmd2 = 'cp /usr/lib/enigma2/python/Plugins/Extensions/SetupHDskin/icon/files/2/skin_templatesVolume.xml /usr/share/enigma2/my_SKIN_HD'
        cmd3 = 'cp /usr/lib/enigma2/python/Plugins/Extensions/SetupHDskin/icon/files/2/Volume.py /usr/lib/enigma2/python/Screens'
        os.system(cmd)
        os.system(cmd1)
        os.system(cmd2)
        os.system(cmd3)
        restartbox = self.session.openWithCallback(self.restartGUI,MessageBox,_("To activate a progress bar will need to restart the system. Do it now?"), MessageBox.TYPE_YESNO, timeout = 7)		
       	self.close        

    def volN(self):	
        cmd = 'rm /usr/share/enigma2/my_SKIN_HD/skin_volume.xml'
        cmd1 = 'rm /usr/lib/enigma2/python/Screens/Volume.py'
        cmd2 = 'cp /usr/lib/enigma2/python/Plugins/Extensions/SetupHDskin/icon/files/3/skin_templatesVolume.xml /usr/share/enigma2/my_SKIN_HD'
        cmd3 = 'cp /usr/lib/enigma2/python/Plugins/Extensions/SetupHDskin/icon/files/3/Volume.py /usr/lib/enigma2/python/Screens'
        os.system(cmd)
        os.system(cmd1)
        os.system(cmd2)
        os.system(cmd3)
        restartbox = self.session.openWithCallback(self.restartGUI,MessageBox,_("To activate a progress bar will need to restart the system. Do it now?"), MessageBox.TYPE_YESNO, timeout = 7)		
       	self.close
               
    def restartGUI(self, answer):
        if answer is True:
            self.session.open(TryQuitMainloop, 3)               		                                                                                                           			

    def ExitV(self):
        self.close()
        
class Mmenu(Screen):
    skin = """
        <screen name="Mmenu" position="center,center" size="620,520" >
            <widget source="menu" render="Listbox" position="20,20" size="580,120" backgroundColor="#30000000" backgroundColorSelected="#00000000" foregroundColor="white" foregroundColorSelected="#1874CD" enableWrapAround="1" scrollbarMode="showNever" transparent="1" >
		<convert type="TemplatedMultiContent">
			{"template": [	MultiContentEntryText(pos = (40,0), size = (500,40), flags = RT_HALIGN_CENTER | RT_VALIGN_CENTER, text = 0) ],
			"fonts": [gFont("Regular", 22)],
			"itemHeight": 40}
		</convert>
            </widget> 
            <widget name="logo" position="10,170" size="600,338" pixmap="/usr/lib/enigma2/python/Plugins/Extensions/SetupHDskin/icon/m.png" alphatest="blend" transparent="1" />
      </screen>"""

    def __init__(self, session):
        Screen.__init__(self, session)
        self.setTitle(_("Available types of main menu"))       
        self.session = session
        self['logo'] = Pixmap()
        
        list = []
        list.append((_('Standard view main menu'), 'Original', 'original_menu'))
        list.append((_('Main menu with PIG window'), 'Pig', 'pig_menu'))
        self['menu'] = List(list)
        
        self['actions'] = ActionMap(['OkCancelActions', 'DirectionActions'], {
         'cancel': self.ExitM,
         'ok': self.okClickM,
         'right': self.nextM,
         'down': self.nextM,
         'up': self.prevM,
         'left': self.prevM}, -1)

    def nextM(self):
        if self['menu'].getIndex() + 1 >= self['menu'].count():
            nav = 0
            self['menu'].setIndex(nav)
        else:
            self['menu'].selectNext()
        self.updateM()

    def prevM(self):
        if self['menu'].getIndex() - 1 < 0:
            nav = self['menu'].count() - 1
            self['menu'].setIndex(nav)
        else:
            self['menu'].selectPrevious()
        self.updateM()
        
    def updateM(self):
        if self['menu'].getCurrent()[2] == 'original_menu':
            self['logo'].instance.setPixmapFromFile(iconpath + 'm.png')
        elif self['menu'].getCurrent()[2] == 'pig_menu':
            self['logo'].instance.setPixmapFromFile(iconpath + 'm1.png')            
            
    def okClickM(self):
        name = self['menu'].getCurrent()
        if name is not None:
            if name[1] == 'Original':
                self.menuO()
            elif name[1] == 'Pig':
               	self.menuP()
                
    def menuO(self):	
        cmd = 'rm /usr/share/enigma2/my_SKIN_HD/skin.xml'
        cmd1 = 'cp /usr/lib/enigma2/python/Plugins/Extensions/SetupHDskin/icon/files/11/skin.xml /usr/share/enigma2/my_SKIN_HD'
        os.system(cmd)
        os.system(cmd1)
        restartbox = self.session.openWithCallback(self.restartGUI,MessageBox,_("To activate the selected appearance of the main menu you need to restart the system. Do it now?"), MessageBox.TYPE_YESNO, timeout = 7)		
        self.close
        
    def menuP(self):	
        cmd = 'rm /usr/share/enigma2/my_SKIN_HD/skin.xml'
        cmd1 = 'cp /usr/lib/enigma2/python/Plugins/Extensions/SetupHDskin/icon/files/22/skin.xml /usr/share/enigma2/my_SKIN_HD'
        os.system(cmd)
        os.system(cmd1)
        restartbox = self.session.openWithCallback(self.restartGUI,MessageBox,_("To activate the selected appearance of the main menu you need to restart the system. Do it now?"), MessageBox.TYPE_YESNO, timeout = 7)		
       	self.close
               
    def restartGUI(self, answer):
        if answer is True:
            self.session.open(TryQuitMainloop, 3)                       		                                                                                                           			

    def ExitM(self):
        self.close()        
        
class barCS(Screen):
    skin = """
        <screen name="barCS" position="center,center" size="620,520" >
            <widget source="menu" render="Listbox" position="20,20" size="580,120" backgroundColor="#30000000" backgroundColorSelected="#00000000" foregroundColor="white" foregroundColorSelected="#1874CD" enableWrapAround="1" scrollbarMode="showNever" transparent="1" >
		<convert type="TemplatedMultiContent">
			{"template": [	MultiContentEntryText(pos = (40,0), size = (500,40), flags = RT_HALIGN_CENTER | RT_VALIGN_CENTER, text = 0) ],
			"fonts": [gFont("Regular", 22)],
			"itemHeight": 40}
		</convert>
            </widget> 
            <widget name="logo" position="10,170" size="600,338" pixmap="/usr/lib/enigma2/python/Plugins/Extensions/SetupHDskin/icon/cs.png" alphatest="blend" transparent="1" />
      </screen>"""

    def __init__(self, session):
        Screen.__init__(self, session)
        self.setTitle(_("Available types of channel selector"))       
        self.session = session
        self['logo'] = Pixmap()
        
        list = []
        list.append((_('The original channel selector'), 'originalCS', 'original_cs'))
        list.append((_('Channel selector with PIG window'), 'pigCS', 'pig_cs'))
        self['menu'] = List(list)
        
        self['actions'] = ActionMap(['OkCancelActions', 'DirectionActions'], {
         'cancel': self.ExitS,
         'ok': self.okClickS,
         'right': self.nextS,
         'down': self.nextS,
         'up': self.prevS,
         'left': self.prevS}, -1)

    def nextS(self):
        if self['menu'].getIndex() + 1 >= self['menu'].count():
            nav = 0
            self['menu'].setIndex(nav)
        else:
            self['menu'].selectNext()
        self.updateS()

    def prevS(self):
        if self['menu'].getIndex() - 1 < 0:
            nav = self['menu'].count() - 1
            self['menu'].setIndex(nav)
        else:
            self['menu'].selectPrevious()
        self.updateS()
        
    def updateS(self):
        if self['menu'].getCurrent()[2] == 'original_cs':
            self['logo'].instance.setPixmapFromFile(iconpath + 'cs.png')
        elif self['menu'].getCurrent()[2] == 'pig_cs':
            self['logo'].instance.setPixmapFromFile(iconpath + 'cs1.png')            
            
    def okClickS(self):
        name = self['menu'].getCurrent()
        if name is not None:
            if name[1] == 'originalCS':
                self.ocs()
            elif name[1] == 'pigCS':
               	self.pigcs()
                
    def ocs(self):	
        cmd = 'rm /usr/share/enigma2/my_SKIN_HD/skin_templatesCS.xml'
        cmd1 = 'cp /usr/lib/enigma2/python/Plugins/Extensions/SetupHDskin/icon/files/11/skin_templatesCS.xml /usr/share/enigma2/my_SKIN_HD'
        os.system(cmd)
        os.system(cmd1)
        restartbox = self.session.openWithCallback(self.restartGUI,MessageBox,_("To activate the selected appearance channel selector will need to restart the system. Do it now?"), MessageBox.TYPE_YESNO, timeout = 7)		
        self.close
        
    def pigcs(self):	
        cmd = 'rm /usr/share/enigma2/my_SKIN_HD/skin_templatesCS.xml'
        cmd1 = 'cp /usr/lib/enigma2/python/Plugins/Extensions/SetupHDskin/icon/files/22/skin_templatesCS.xml /usr/share/enigma2/my_SKIN_HD'
        os.system(cmd)
        os.system(cmd1)
        restartbox = self.session.openWithCallback(self.restartGUI,MessageBox,_("To activate the selected appearance channel selector will need to restart the system. Do it now?"), MessageBox.TYPE_YESNO, timeout = 7)		
       	self.close
               
    def restartGUI(self, answer):
        if answer is True:
            self.session.open(TryQuitMainloop, 3)                       		                                                                                                           			

    def ExitS(self):
        self.close()        
                                              
def OpenSetup(session, **kwargs):
	session.open(SetupHDskin)

def StartSetup(menuid, **kwargs):
	if menuid == "system":
		return [(_("SetupHDskin"), OpenSetup, "skin_setup", None)]
	else:
		return []

def Plugins(**kwargs):
	return [PluginDescriptor(where = PluginDescriptor.WHERE_MENU, fnc = StartSetup)]
	