################################################################################
#    MyEnigmaTranslation - Enigma2 plugin for OpenPLi
#    Version: 1.0-rc5 (05.12.2012 19:50)
#    Copyright (C) 2012 vlamo <vlamodev@gmail.com>
#
#    This program is free software; you can redistribute it and/or modify
#    it under the terms of the GNU General Public License as published by
#    the Free Software Foundation; either version 2 of the License, or
#    (at your option) any later version.
#
#    This program is distributed in the hope that it will be useful,
#    but WITHOUT ANY WARRANTY; without even the implied warranty of
#    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#    GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License along
#    with this program; if not, write to the Free Software Foundation, Inc.,
#    51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.
################################################################################

from . import _, PLUGIN_NAME, PLUGIN_PATH
from Components.config import config, ConfigSubsection, ConfigYesNo
import os, gettext, locale

config.plugins.MyEnigmaTranslation = ConfigSubsection()
config.plugins.MyEnigmaTranslation.enabled = ConfigYesNo(default=True)

DEFAULT_DOMAIN = gettext._current_domain
ENIGMA2_DOMAIN = 'enigma2'

def getLanguageList():
	try:
		langlist = [x for x in os.listdir('%s/locale' % PLUGIN_PATH) if os.path.exists('%s/locale/%s/LC_MESSAGES/enigma2.mo' % (PLUGIN_PATH, x))]
		langlist.sort()
	except:
		langlist = [ ]
	return langlist

def activateLanguage(self, index, dont_use_callbacks=False):
	if str(index)[:2] in getLanguageList():
		try:
			lang = self.lang[index]
			print "[%s] Activating language: %s" % (PLUGIN_NAME, lang[0])
			gettext.translation('enigma2', "%s/locale" % PLUGIN_PATH, languages=[lang[1]]).install(names=("ngettext", "pgettext"))
			self.activeLanguage = index
			
			if not dont_use_callbacks:
				for x in self.callbacks:
					x()
		except KeyError, e:
			print "[%s] Selected language '%s' does not exist!" % (PLUGIN_NAME, index)
		except (IOError,Exception), e:
			print "[%s] Activating language error: %s" % (PLUGIN_NAME, e)
			self.defaultActivateLanguage(index)
			return
		else:
			#print "[%s] Set default text domain: %s" % (PLUGIN_NAME, ENIGMA2_DOMAIN)
			gettext.textdomain(ENIGMA2_DOMAIN)
			#print "[%s] Bind default text domain, path: %s/locale" % (PLUGIN_NAME, PLUGIN_PATH)
			gettext.bindtextdomain(ENIGMA2_DOMAIN, "%s/locale" % PLUGIN_PATH)
			
		lang = self.getLanguage()
		try:
			locale.setlocale(locale.LC_TIME, (lang, 'UTF-8'))
		except:
			print "[%s] Failed to set LC_TIME to %s. Setting it to 'C'" % (PLUGIN_NAME, lang)
			locale.setlocale(locale.LC_TIME, 'C')
		
		os.environ["LC_TIME"] = lang + '.UTF-8'
	else:
		if ENIGMA2_DOMAIN in gettext._localedirs:
			#print "[%s] UnBind default text domain, path: %s" % (PLUGIN_NAME, gettext._localedirs[ENIGMA2_DOMAIN])
			del gettext._localedirs[ENIGMA2_DOMAIN]
		if gettext._current_domain != DEFAULT_DOMAIN:
			#print "[%s] Set default text domain: %s" % (PLUGIN_NAME, DEFAULT_DOMAIN)
			gettext.textdomain(DEFAULT_DOMAIN)
		self.defaultActivateLanguage(index)

def getPluginName(self, name):
	return _(name)

def StartMainSession(reason, **kwargs):
	if reason <> 0 or not config.plugins.MyEnigmaTranslation.enabled.value: return
	
	import Components.Language
	if not hasattr(Components.Language.Language, 'defaultActivateLanguage'):
		#print '[%s] substitution PluginList' % (PLUGIN_NAME)
		import Components.PluginList
		try:
			import PluginList
			Components.PluginList.PluginEntryComponent = PluginList.PluginEntryComponent
			Components.PluginList.PluginCategoryComponent = PluginList.PluginCategoryComponent
			Components.PluginList.PluginDownloadComponent = PluginList.PluginDownloadComponent
		except Exception, e:
			print '[%s] substitution PluginList failed: %s' % (PLUGIN_NAME, e)
		else:
			#print '[%s] substitution base PluginBrowser' % (PLUGIN_NAME)
			import Screens.PluginBrowser
			try:
				Screens.PluginBrowser.PluginEntryComponent = Components.PluginList.PluginEntryComponent
				Screens.PluginBrowser.PluginCategoryComponent = Components.PluginList.PluginCategoryComponent
				Screens.PluginBrowser.PluginDownloadComponent = Components.PluginList.PluginDownloadComponent
			except Exception, e:
				print '[%s] substitution base PluginBrowser failed: %s' % (PLUGIN_NAME, e)
			else:
				#print '[%s] default PluginBrowser is %r' % (PLUGIN_NAME, Screens.PluginBrowser.PluginBrowser)
				if Screens.PluginBrowser.PluginBrowser.__module__ != "Screens.PluginBrowser":
					#print '[%s] substitution new PluginBrowser' % (PLUGIN_NAME)
					from Tools.Import import my_import
					try:
						NewPluginBrowserModule = my_import(Screens.PluginBrowser.PluginBrowser.__module__)
						NewPluginBrowserModule.PluginEntryComponent = Components.PluginList.PluginEntryComponent
						NewPluginBrowserModule.PluginCategoryComponent = Components.PluginList.PluginCategoryComponent
						NewPluginBrowserModule.PluginDownloadComponent = Components.PluginList.PluginDownloadComponent
					except Exception, e:
						print '[%s] substitution new PluginBrowser failed: %s' % (PLUGIN_NAME, e)
		#print '[%s] substitution Language.activateLanguage' % (PLUGIN_NAME)
		Components.Language.Language.defaultActivateLanguage = Components.Language.Language.activateLanguage
		Components.Language.Language.activateLanguage = activateLanguage
		#print '[%s] current activeLanguage is %r' % (PLUGIN_NAME, str(Components.Language.language.activeLanguage)[:2])
		if str(Components.Language.language.activeLanguage)[:2] in getLanguageList():
			#print '[%s] reload activeLanguage %r' % (PLUGIN_NAME, str(Components.Language.language.activeLanguage)[:2])
			Components.Language.language.activateLanguage(Components.Language.language.activeLanguage, dont_use_callbacks=True)
			#print '[%s] (re)translate names and descriptions in system plugins list' % (PLUGIN_NAME)
			from Components.PluginComponent import plugins
			for x in plugins.plugins:
				for y in range(len(plugins.plugins[x])):
					plugins.plugins[x][y].name = _(plugins.plugins[x][y].name)
					plugins.plugins[x][y].description = _(plugins.plugins[x][y].description)

def OpenSetupScreen(session, **kwargs):
	import MyEnigmaTranslationSetup
	session.open(MyEnigmaTranslationSetup.MyEnigmaTranslationSetup)

from Plugins.Plugin import PluginDescriptor
def Plugins(**kwargs):
	return [PluginDescriptor(where = [PluginDescriptor.WHERE_AUTOSTART], fnc = StartMainSession),
		PluginDescriptor(name = _(PLUGIN_NAME), description = _("Alternative localization enigma2"), where = [PluginDescriptor.WHERE_PLUGINMENU], fnc = OpenSetupScreen)]
